@@ -444,6 +444,7 @@ class ImportAdmin(IDAdmin):
                 # 必须仿照navicat的处理方式, 设置batch_size, 小批量处理数据.
                 # 同时出现问题, 如何让用户看到进度条? 用异步的方式, 或者websocket?
                 md_ls = []
+                md_dc_ls = []
                 my_tqdm = tqdm(total=df_rows)
                 for index, row in df1.iterrows():
                     content_ls = row.values.tolist()
@@ -494,8 +495,12 @@ class ImportAdmin(IDAdmin):
                         dc.update({'pk': curr_id})
                         curr_id += 1
 
-                    md = self.model(**dc)
-                    md_ls.append(md)
+                    if self.use_bulk_create:
+                        md = self.model(**dc)
+                        md_ls.append(md)
+                    else:
+                        md_dc_ls.append(dc)
+
                     my_tqdm.update(1)
 
                     # if self.use_bulk_create is False:
@@ -506,9 +511,9 @@ class ImportAdmin(IDAdmin):
                 else:
                     save_tqdm = tqdm(total=df_rows)
                     save_tqdm.desc = '写入数据库ing...'
-                    for md_i in md_ls:
+                    for md_dc_i in md_dc_ls:
                         save_tqdm.update(1)
-                        md_i.save()
+                        self.model.objects.create(**md_dc_i)                 # `md_i.save()`不太好, 容易覆盖原有数据
 
                 reset_db_sequence(self.model)
                 self.message_user(request, f"{f_format}文件导入成功! 一共导入{df_rows}条数据, 耗时: {t_import.now(1)}秒.")
